==> ep-framework-gath-2.1.31-2a8979.tar: src/Plugin/Images.php <==
<?php

namespace Ep\Gath\Plugin;

/**
 * Prepoznaje slike iz Gatha kao attachmente.
 *
 * @package Ep\Gath\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/gath
 */
class Images extends AbstractGathPlugin
{
    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function attach(): void
    {
        add_filter('wp_get_attachment_image_src', [$this, 'get_attachment_image_src'], 10, 3);
    }

    /**
     * Ako je kao $attachment_id poslan string koji počinje sa 'gath-', vraća
     * URL te slike na servisu sa slikama.
     *
     * @param $image
     * @param $attachment_id
     * @param $size
     *
     * @return array
     */
    public function get_attachment_image_src($image, $attachment_id, $size)
    {
        if (preg_match('/^gath-(.*)$/', $attachment_id, $matches)) {
            if (strlen($matches[1]) > 0) {
                $imageUrl = $this->getImageUrl($matches[1], $size);
                $size = [0, 0];//@getimagesize('https:' . $imageUrl);
                return [$imageUrl, $size[0], $size[1]];
            }
        } elseif (preg_match('/^external-(.*)$/', $attachment_id, $matches)) {
            if (strlen($matches[1]) > 0) {
                $imageUrl = $this->getExternalImageUrl($matches[1]);
                return [$imageUrl, null, null];
            }
        }

        return $image;
    }

    /**
     * Vraca string https://server.tld/external/external-host.tld/path/slika.jpg
     *
     * @param $url
     * @return string
     */
    public function getExternalImageUrl($url)
    {
        return sprintf('https://%s/external/%s', $_SERVER['HTTP_HOST'], $url);
    }

    /**
     * Generira URL za datu sliku.
     *
     * @param $path
     * @param string $size
     * @param bool $cropped
     *
     * @return string
     */
    public function getImageUrl($path, $size = 'full', $cropped = false)
    {
        $baseUri = rtrim(preg_replace('/^https?:/', '', $this->gath->getImageBaseUri()), '/');

        if (empty($baseUri)) {
            throw new \RuntimeException('Nije zadan osnovni URI servisa sa slikama.');
        }

        $parts = [];

        if ($size !== 'full') {
            if (is_string($size)) {
                global $_wp_additional_image_sizes;

                if (!isset($_wp_additional_image_sizes[$size]) && !in_array($size, ['thumbnail', 'medium', 'medium_large', 'large'])) {
                    throw new \RuntimeException(sprintf("Nepoznata veličina slike '%s'.", $size));
                }

                if (in_array($size, ['thumbnail', 'medium', 'medium_large', 'large'])) {
                    $width = get_option("{$size}_size_w");
                    $height = get_option("{$size}_size_h");
                    $cropped = (bool)get_option("{$size}_crop");
                } else {
                    $width = $_wp_additional_image_sizes[$size]['width'];
                    $height = $_wp_additional_image_sizes[$size]['height'];
                    $cropped = $_wp_additional_image_sizes[$size]['crop'];
                }
            } else if (is_array($size)) {
                [$width, $height] = $size;
            } else {
                throw new \RuntimeException(sprintf(
                    "Neispravan parametar \$size, mora biti string ili array a dobio sam %s.",
                    is_object($size) ? get_class($size) : gettype($size)
                ));
            }

            $parts[] = sprintf('%sx%s', $width, $height);
        }

        if (!preg_match('/wptest/', $baseUri)) {
            if ($cropped) {
                array_unshift($parts, 'thumb');
            } else if (isset($width) && isset($height) && $width !== 0 && $height !== 0) {
                array_unshift($parts, 'fit');
            }
        }

        $parts[] = implode('/', array_map('rawurlencode', explode('/', $path)));

        return sprintf('%s/%s', $baseUri, implode('/', $parts));
    }
}

==> ep-framework-gath-2.1.32-085a73.tar: src/Plugin/Images.php <==
<?php

namespace Ep\Gath\Plugin;

use RuntimeException;
use function curl_exec;
use function curl_init;
use function curl_setopt;

/**
 * Prepoznaje slike iz Gatha kao attachmente.
 *
 * @package Ep\Gath\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/gath
 */
class Images extends AbstractGathPlugin
{
    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function attach(): void
    {
        add_filter('wp_get_attachment_image_src', [$this, 'get_attachment_image_src'], 10, 3);
    }

    /**
     * Ako je kao $attachment_id poslan string koji počinje sa 'gath-', vraća
     * URL te slike na servisu sa slikama.
     *
     * @param $image
     * @param $attachment_id
     * @param $size
     *
     * @return array
     */
    public function get_attachment_image_src($image, $attachment_id, $size)
    {
        if (preg_match('/^gath-(.*)$/', $attachment_id, $matches)) {
            if (strlen($matches[1]) > 0) {
                $imageUrl = $this->getImageUrl($matches[1], $size);
                $url = 'https:' . $imageUrl;

                if ($this->checkRemoteFile($url)) {
                    $size = @getimagesize($url);
                    return [$imageUrl, $size[0] ?? 0, $size[1] ?? 0];
                } else {
                    return [$imageUrl, null, null];
                }
            }
        } elseif (preg_match('/^external-(.*)$/', $attachment_id, $matches)) {
            if (strlen($matches[1]) > 0) {
                $imageUrl = $this->getExternalImageUrl($matches[1]);
                return [$imageUrl, null, null];
            }
        }

        return $image;
    }

    private function checkRemoteFile(string $url): bool
    {
        $timeout = 2;

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_NOBODY, 1);
        curl_setopt($ch, CURLOPT_FAILONERROR, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);

        return (curl_exec($ch) !== false);
    }

    /**
     * Vraca string https://server.tld/external/external-host.tld/path/slika.jpg
     *
     * @param $url
     * @return string
     */
    public function getExternalImageUrl($url)
    {
        return sprintf('https://%s/external/%s', $_SERVER['HTTP_HOST'], $url);
    }

    /**
     * Generira URL za datu sliku.
     *
     * @param $path
     * @param string $size
     * @param bool $cropped
     *
     * @return string
     */
    public function getImageUrl($path, $size = 'full', $cropped = false)
    {
        $baseUri = rtrim(preg_replace('/^https?:/', '', $this->gath->getImageBaseUri()), '/');

        if (empty($baseUri)) {
            throw new RuntimeException('Nije zadan osnovni URI servisa sa slikama.');
        }

        $parts = [];

        if ($size !== 'full') {
            if (is_string($size)) {
                global $_wp_additional_image_sizes;

                if (!isset($_wp_additional_image_sizes[$size]) && !in_array($size, ['thumbnail', 'medium', 'medium_large', 'large'])) {
                    throw new RuntimeException(sprintf("Nepoznata veličina slike '%s'.", $size));
                }

                if (in_array($size, ['thumbnail', 'medium', 'medium_large', 'large'])) {
                    $width = get_option("{$size}_size_w");
                    $height = get_option("{$size}_size_h");
                    $cropped = (bool)get_option("{$size}_crop");
                } else {
                    $width = $_wp_additional_image_sizes[$size]['width'];
                    $height = $_wp_additional_image_sizes[$size]['height'];
                    $cropped = $_wp_additional_image_sizes[$size]['crop'];
                }
            } else if (is_array($size)) {
                [$width, $height] = $size;
            } else {
                throw new RuntimeException(sprintf(
                    "Neispravan parametar \$size, mora biti string ili array a dobio sam %s.",
                    is_object($size) ? get_class($size) : gettype($size)
                ));
            }

            $parts[] = sprintf('%sx%s', $width, $height);
        }

        if (!preg_match('/wptest/', $baseUri)) {
            if ($cropped) {
                array_unshift($parts, 'thumb');
            } else if (isset($width) && isset($height) && $width !== 0 && $height !== 0) {
                array_unshift($parts, 'fit');
            }
        }

        $parts[] = implode('/', array_map('rawurlencode', explode('/', $path)));

        return sprintf('%s/%s', $baseUri, implode('/', $parts));
    }
}
